
// ><(((*> <(((*> ><(((*> ><(((*> ><(((*> ><(((*> ><(((*> ><(((*> ><(((*>
//
//          streamCapture2 (DownloadListDialog)
//          (C) Copyright  2016 - 2024 Ingemar Ceicer
//          https://gitlab.com/posktomten/streamcapture2/
//          programming@ceicer.com
//
//   This program is free software: you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
// ><(((*> <(((*> ><(((*> ><(((*> ><(((*> ><(((*> ><(((*> ><(((*> ><(((*>

#include "newprg.h"
#include "downloadlistdialog.h"
#include "ui_downloadlistdialog.h"
#include <QTextStream>
#include <QMessageBox>
#include <QFileDialog>
#include <QFontDatabase>
#include <QSettings>
#include <QStandardPaths>
#include <QRegularExpression>
#include <QCloseEvent>

DownloadListDialog::DownloadListDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DownloadListDialog)
{
    ui->setupUi(this);
    // QShortcut *zoomD = new QShortcut((QKeySequence(Qt::Key_0)),
    //                                  this);
    // connect(zoomD, &QShortcut::activated, this, &DownloadListDialog::zoomDefault);
    // QShortcut *zoomM = new QShortcut((QKeySequence(Qt::Key_Minus)),
    //                                  this);
    // connect(zoomM, &QShortcut::activated, this, &DownloadListDialog::zoomMinus);
    // QShortcut *zoomP = new QShortcut((QKeySequence(Qt::Key_Plus)),
    //                                  this);
    // connect(zoomP, &QShortcut::activated, this, &DownloadListDialog::zoomPlus);
    QShortcut *zoomD = new QShortcut((QKeySequence(Qt::CTRL | Qt::Key_0)),
                                     this);
    connect(zoomD, &QShortcut::activated, this, &DownloadListDialog::zoomDefault);
    ///
    QShortcut *zoomM = new QShortcut((QKeySequence(Qt::CTRL | Qt::Key_Minus)),
                                     this);
    connect(zoomM, &QShortcut::activated, this, &DownloadListDialog::zoomMinus);
    ///
    QShortcut *zoomP = new QShortcut((QKeySequence(Qt::CTRL | Qt::Key_Plus)),
                                     this);
    connect(zoomP, &QShortcut::activated, this, &DownloadListDialog::zoomPlus);
    ///
#ifdef Q_OS_WINDOWS
#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
    this->setWindowFlags(this->windowFlags() & ~Qt::WindowContextHelpButtonHint);
#endif
#endif
    QSettings settings(QSettings::IniFormat, QSettings::UserScope, DISPLAY_NAME,
                       EXECUTABLE_NAME);
    // settings.setIniCodec("UTF-8");
    settings.beginGroup("Downloadlistdialog");
    restoreGeometry(settings.value("geometry").toByteArray());
    settings.endGroup();
// change textedit palette
    /* Font */
#if defined(Q_OS_WINDOWS)
    int id = QFontDatabase::addApplicationFont(":/fonts/segoeui.ttf");
#endif
#if defined(Q_OS_LINUX)
    int id = QFontDatabase::addApplicationFont(":/fonts/Ubuntu-M.ttf");
#endif
    QString _family = QFontDatabase::applicationFontFamilies(id).at(0);
    QFont _font(_family, FONTSIZE);
    QApplication::setFont(_font);
    QFont systemfont = QApplication::font();
    this->setFont(systemfont);
    settings.beginGroup("Font");
    QString family = settings.value("family", systemfont).toString();
    int size = settings.value("size", systemfont.pointSize()).toInt();
    bool bold = settings.value("bold", false).toBool();
    bool italic = settings.value("italic", false).toBool();
    bool boldItalic = settings.value("boldItalic", false).toBool();
    settings.endGroup();
    QFont f2(family, size);
    ui->textEdit->setFont(f2);

    if(boldItalic) {
        ui->textEdit->setStyleSheet("font-weight: bold; font-style: italic");
    } else {
        if(bold) {
            ui->textEdit->setStyleSheet("font-weight: bold");
        } else if(italic) {
            ui->textEdit->setStyleSheet("font-style: italic");
        }
    }

    QTextCursor cursor = ui->textEdit->textCursor();
    ui->textEdit->selectAll();
    ui->textEdit->setTextCursor(cursor);
    connect(ui->pbSave, &QPushButton::clicked, [this]() {
        QString *data =  new QString(ui->textEdit->toPlainText());
        emit sendContent(data);
    });
    connect(ui->pbSaveAs, &QPushButton::clicked, [ this ]() {
        QSettings settings(QSettings::IniFormat, QSettings::UserScope, DISPLAY_NAME,
                           EXECUTABLE_NAME);
        // settings.setIniCodec("UTF-8");
        settings.beginGroup("Downloadlistdialog");
        QString copyfileto = settings.value("copyfileto", QStandardPaths::writableLocation(QStandardPaths::HomeLocation)).toString();
        settings.endGroup();
        int x = this->x();
        int y = this->y();
        QFileDialog *dialog = new QFileDialog(this);
        dialog->setLabelText(QFileDialog::Accept, tr("Save"));
        dialog->setLabelText(QFileDialog::Reject, tr("Cancel"));
        dialog->setWindowTitle(tr("Save as text file"));
        dialog->setGeometry(x + 50, y + 50, 900, 550);
        dialog->setViewMode(QFileDialog::Detail);
        dialog->setFileMode(QFileDialog::AnyFile);
        dialog->setDirectory(copyfileto);
        dialog->setAcceptMode(QFileDialog::AcceptSave);
        // ipac
        QStringList filters;
#if defined(Q_OS_LINUX)
        filters << tr("Text file") + " (*.txt)" << tr("Text file, optional extension") + " (*)";
        dialog->setNameFilters(filters);
#elif defined(Q_OS_WINDOWS)
        filters << tr("Text file") + " (*.txt)" << tr("Text file, optional extension") + " (*.*)";
        dialog->setNameFilters(filters);
#endif

        if(dialog->exec() == 1) {
#if defined(Q_OS_LINUX)

            if(dialog->selectedNameFilter() == tr("Text file") + " (*.txt)") {
                dialog->setDefaultSuffix(".txt");
            }

#endif
            QString newfile = dialog->selectedFiles().at(0);
            QFileInfo fi(newfile);
            QString path = fi.absolutePath();
            QFileInfo fi1(path);

            if(!fi1.isWritable()) {
                QMessageBox msgBox;
                msgBox.setIcon(QMessageBox::Critical);
                msgBox.setWindowTitle(DISPLAY_NAME " " VERSION);
                msgBox.setText(tr("Could not save the file.\nCheck your file permissions."));
                msgBox.addButton(tr("Ok"), QMessageBox::AcceptRole);
                msgBox.exec();
                return;
            }

            QFile file_newfile(newfile);
            QString text = ui->textEdit->toPlainText();
            static QRegularExpression qre("[\r\n]");
            static QStringList list = text.split(qre, Qt::KeepEmptyParts);
            file_newfile.open(QIODevice::WriteOnly | QIODevice::Text);
            QTextStream outStream(&file_newfile);
#if QT_VERSION > QT_VERSION_CHECK(5, 15, 21)

            for(const QString &s : std::as_const(list)) {
                outStream << s + "\n";
            }

#else

            for(const QString &s : qAsConst(list)) {
                outStream << s + "\n";
            }

#endif
            file_newfile.close();
            fi.setFile(file_newfile);
            copyfileto = fi.absolutePath();
            settings.beginGroup("Downloadlistdialog");
            settings.setValue("copyfileto", copyfileto);
            settings.endGroup();
        }
    });
    connect(ui->pbClose, &QPushButton::clicked, [this]() {
        close();
    });
}
void DownloadListDialog::initiate(const QStringList * instructions, const QString * content, bool readonly)
{
    this->setWindowTitle(instructions->at(0));
    ui->textEdit->clear();

    if(readonly) {
        ui->textEdit->setReadOnly(true);
        ui->pbSave->setDisabled(true);
        ui->pbSave->hide();
    }

    static QRegularExpression qre("[\n]");
    QStringList strList = content->split(qre, Qt::SplitBehavior(Qt::KeepEmptyParts));
#if QT_VERSION > QT_VERSION_CHECK(5, 15, 21)

    for(const QString &s : std::as_const(strList)) {
        ui->textEdit->insertHtml(s + "<br>");
    }

#else

    for(const QString &s : qAsConst(strList)) {
        ui->textEdit->insertHtml(s + "<br>");
    }

#endif
    ui->textEdit->moveCursor(QTextCursor::Start);
    this->show();
}

void DownloadListDialog::openFile(const QStringList * instructions, const QString * filename, bool readonly)
{
    this->setWindowTitle(instructions->at(0));
    ui->textEdit->clear();
    // ui->textEdit->setFont(f2);

    if(readonly) {
        ui->textEdit->setReadOnly(true);
        ui->pbSave->setDisabled(true);
        ui->pbSave->hide();
    }

    // 3 argument
    //**************************************************************************
    if(instructions->length() == 3) {
        if(instructions->at(1) == QString("wordwrap")) {
            ui->textEdit->setWordWrapMode(QTextOption::WordWrap);
        } else {
            ui->textEdit->setWordWrapMode(QTextOption::WrapAnywhere);
        }

        QTextDocument *tdoc = new QTextDocument;
        tdoc->setDefaultStyleSheet(instructions->at(2));
        QFile file(*filename);
        QString content;

        if(!file.exists()) {
            int hittat = filename->lastIndexOf('/');
            QString filnamnet = filename->mid(hittat + 1);
            QMessageBox msgBox;
            msgBox.setIcon(QMessageBox::Warning);
            msgBox.setWindowTitle(tr("Unable to find file"));
            msgBox.setText(tr("Unable to find") + " \"" + filnamnet + "\"");
            msgBox.addButton(tr("Ok"), QMessageBox::AcceptRole);
            msgBox.exec();
        } else {
            file.open(QIODevice::ReadOnly);

            while(!file.atEnd()) {
                content += file.readLine();
            }

            file.close();
        }

        tdoc->setHtml("<html><head><title>Important</title></head><body>" + content + "</body></html>");
        ui->textEdit->moveCursor(QTextCursor::Start);
        ui->textEdit->setDocument(tdoc);
        this->show();
        textBrowsertextEditTextChanged();
        zoomDefault();
        //ui->textEdit->setFont(f2);
        return;
        // 3 argument end
        //******************************************************************
        // 2 argument
    } else if(instructions->length() == 2) {
        if(instructions->at(1) == QString("wordwrap")) {
            ui->textEdit->setWordWrapMode(QTextOption::WordWrap);
        } else {
            ui->textEdit->setWordWrapMode(QTextOption::WrapAnywhere);
        }

        QFile file(*filename);
        QString content;

        if(!file.exists()) {
            int hittat = filename->lastIndexOf('/');
            QString filnamnet = filename->mid(hittat + 1);
            QMessageBox msgBox;
            msgBox.setIcon(QMessageBox::Warning);
            msgBox.setWindowTitle(tr("Unable to find file"));
            msgBox.setText(tr("Unable to find") + " \"" + filnamnet + "\"");
            msgBox.addButton(tr("Ok"), QMessageBox::AcceptRole);
            msgBox.exec();
        } else {
            file.open(QIODevice::ReadOnly);

            while(!file.atEnd()) {
                content += file.readLine() + "<br>";
            }

            file.close();
        }

        ui->textEdit->insertHtml(content);
        // ui->textEdit->insertPlainText(content);
        ui->textEdit->moveCursor(QTextCursor::Start);
        this->show();
        // 2 argument end
    } else {
        return;
    }
}

void DownloadListDialog::closeEvent(QCloseEvent * e)
{
    QSettings settings(QSettings::IniFormat, QSettings::UserScope, DISPLAY_NAME,
                       EXECUTABLE_NAME);
    // settings.setIniCodec("UTF-8");
    settings.beginGroup("Downloadlistdialog");
    settings.setValue("geometry", saveGeometry());
    settings.endGroup();
    emit finished(true);
    e->accept();
}
DownloadListDialog::~DownloadListDialog()
{
    delete ui;
}
